import { ISecurityGroup } from "aws-cdk-lib/aws-ec2";
import { Construct } from "constructs";
import { IActiveMqBroker } from "./activemq-broker";
import { ActiveMqBrokerDeploymentBase, ActiveMqBrokerDeploymentProps, IActiveMqBrokerDeployment } from "./activemq-broker-deployment";
import { ActiveMqBrokerEndpoints } from "./activemq-broker-endpoints";
import { StorageType } from "../storage-type";
export interface IActiveMqBrokerInstance extends IActiveMqBrokerDeployment, IActiveMqBroker {
}
export interface ActiveMqBrokerInstanceProps extends ActiveMqBrokerDeploymentProps {
    /**
     * Sets the storage type of the Amazon MQ for ActiveMQ broker.
     * @default - undefined; EFS will be used.
     */
    readonly storageType?: StorageType;
}
/**
 * A representation of a single-instance broker comprised of one broker in one Availability Zone.
 *
 * Additional optimizations:
 * - When subnet selection returns more then 1 subnets. A first one is picked. Warning is annotated
 *
 *
 * see: https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/single-broker-deployment.html
 */
export declare class ActiveMqBrokerInstance extends ActiveMqBrokerDeploymentBase implements IActiveMqBrokerInstance {
    /**
     * Reference an existing ActiveMQ Broker Instance, defined outside of the CDK code, by ARN.
     *
     * @param scope
     * @param logicalId the construct's logical ID
     * @param arn the ARN of the existing ActiveMQ Broker Instance that is imported
     * @param securityGroups optionally pass security groups for working with network connections
     * @returns a representation of the ActiveMQ Broker Instance
     */
    static fromActiveMqBrokerInstanceArn(scope: Construct, logicalId: string, arn: string, securityGroups?: ISecurityGroup[]): IActiveMqBrokerInstance;
    /**
     * Reference an existing ActiveMQ Broker Instance, defined outside of the CDK code, by its name and id.
     *
     * @param scope
     * @param logicalId
     * @param name the name of the existing ActiveMQ Broker Instance to be imported
     * @param id the ID of the existing ActiveMQ Broker Instance to be imported
     * @param securityGroups (optional) pass security groups for working with network connections
     * @returns a representation of the ActiveMQ Broker Instance
     */
    static fromActiveMqBrokerInstanceNameAndId(scope: Construct, logicalId: string, name: string, id: string, securityGroups?: ISecurityGroup[]): IActiveMqBrokerInstance;
    /**
     *
     * @internal
     */
    private static _assignEndpoints;
    /**
     * Gets the IP address of the ENI of the Amazon MQ for ActiveMQ broker.
     *
     * @attribute
     */
    readonly ipAddress: string;
    /**
     * Gets the available endpoints of the Amazon MQ for ActiveMQ broker.
     */
    readonly endpoints: ActiveMqBrokerEndpoints;
    constructor(scope: Construct, id: string, props: ActiveMqBrokerInstanceProps);
}
